==> tdeaddons-trinity_14.1.3.orig.tar.xz: tdeaddons-trinity-14.1.3/kate/katesort/sortdialog.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Marian Kyral                                    *
 *   mkyral@email.cz                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef SORTDIALOG_H
#define SORTDIALOG_H

#include "sortdialoglayout.h"
#include <tqdialog.h>
#include <tdelocale.h>
#include <tqlineedit.h>
#include <tqpushbutton.h>
#include <tqbuttongroup.h>
#include <tqradiobutton.h>
#include <tqgroupbox.h>
#include <tqcheckbox.h>
#include <tqlabel.h>
#include <tqmessagebox.h>

class SortDialog : public sortdialoglayout
{
		TQ_OBJECT

	public:
		SortDialog ( TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
		~SortDialog();
//    TQCheckBox* m_checkBoxUnique;
    /*$PUBLIC_FUNCTIONS$*/

	public slots:
		/*$PUBLIC_SLOTS$*/
    int   exec();

	protected:
		/*$PROTECTED_FUNCTIONS$*/
    void          config_load();
    void          config_save();
    TDEConfig       *config;

	protected slots:
		/*$PROTECTED_SLOTS$*/
		virtual void          reject();
		virtual void          accept();
    virtual void          toggledCol();
    virtual void          toggledType();

};

#endif

==> tdeaddons-trinity-14.1.5.tar.xz: tdeaddons-trinity-14.1.5/kate/katesort/sortdialog.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Marian Kyral                                    *
 *   mkyral@email.cz                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef SORTDIALOG_H
#define SORTDIALOG_H

#include "sortdialoglayout.h"
#include <tqdialog.h>
#include <tdelocale.h>
#include <tqlineedit.h>
#include <tqpushbutton.h>
#include <tqbuttongroup.h>
#include <tqradiobutton.h>
#include <tqgroupbox.h>
#include <tqcheckbox.h>
#include <tqlabel.h>
#include <tqmessagebox.h>

class SortDialog : public sortdialoglayout
{
		TQ_OBJECT

	public:
		SortDialog ( TQWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
		~SortDialog();
//    TQCheckBox* m_checkBoxUnique;
    /*$PUBLIC_FUNCTIONS$*/

	public slots:
		/*$PUBLIC_SLOTS$*/
    int   exec();

	protected:
		/*$PROTECTED_FUNCTIONS$*/
    void          config_load();
    void          config_save();
    TDEConfig       *config;

	protected slots:
		/*$PROTECTED_SLOTS$*/
		virtual void          reject();
		virtual void          accept();
    virtual void          toggledCol();
    virtual void          toggledType();

};

#endif
